# Vue.js (Vuelidate)

A fully interactive Vue component with form validation.

Success! Form submitted successfully! The secret is: dumbledore

### Registration Form

Email Address
Please enter a valid email address
Country
Country is required
Preferred Meeting Date
Meeting date is required
Contact Preference
Email
Phone
Text Message
Please select a contact preference
File Upload
Please upload a file